============
Introduction
============

This project contains documentation and code for integrating Project Calico's
networking into OpenStack/Neutron.

Calico is an open source solution for virtual networking in cloud data centers,
developed principally by Metaswitch Networks and released under the Apache 2.0
License.

For all technical documentation, please see
http://docs.projectcalico.org/en/latest/index.html.

For documentation specifically about using Calico with OpenStack - which is the
concern of this Launchpad project - please see
http://docs.projectcalico.org/en/latest/openstack.html.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/networking-calico
* Source: http://git.openstack.org/cgit/openstack/networking-calico
* Bugs: http://bugs.launchpad.net/networking-calico
